@@ -82,6 +82,7 @@ set_date (TrackerSparqlCursor *cursor,
 {
   const gchar *str = tracker_sparql_cursor_get_string (cursor, column, NULL);
   if (key == GRL_METADATA_KEY_CREATION_DATE
+      || key == GRL_METADATA_KEY_LAST_PLAYED
       || key == GRL_METADATA_KEY_MODIFICATION_DATE) {
     GDateTime *date = grl_date_time_from_iso8601 (str);
     if (date) {
@@ -275,6 +276,31 @@ grl_tracker_setup_key_mappings (void)
                       "nfo:duration(?urn)",
                       "audio");
 
+  insert_key_mapping (GRL_METADATA_KEY_MB_TRACK_ID,
+                      "nmm:mbTrackID",
+                      "nmm:mbTrackID(?urn)",
+                      "audio");
+
+  insert_key_mapping (GRL_METADATA_KEY_MB_ARTIST_ID,
+                      "nmm:mbArtistID",
+                      "nmm:mbArtistID(?urn)",
+                      "audio");
+
+  insert_key_mapping (GRL_METADATA_KEY_MB_RECORDING_ID,
+                      "nmm:mbRecordingID",
+                      "nmm:mbRecordingID(?urn)",
+                      "audio");
+
+  insert_key_mapping (GRL_METADATA_KEY_MB_RELEASE_ID,
+                      "nmm:mbReleaseID",
+                      "nmm:mbReleaseID(?urn)",
+                      "audio");
+
+  insert_key_mapping (GRL_METADATA_KEY_MB_RELEASE_GROUP_ID,
+                      "nmm:mbReleaseGroupID",
+                      "nmm:mbReleaseGroupID(?urn)",
+                      "audio");
+
   insert_key_mapping (GRL_METADATA_KEY_FRAMERATE,
                       "nfo:frameRate",
                       "nfo:frameRate(?urn)",
@@ -658,6 +684,8 @@ grl_tracker_build_grilo_media_default (GHashTable *ht)
     return grl_media_container_new ();
   } else if (g_hash_table_lookup (ht, RDF_TYPE_FOLDER)) {
     return grl_media_container_new ();
+  } else if (g_hash_table_lookup (ht, RDF_TYPE_PLAYLIST)) {
+    return grl_media_container_new ();
   }
 
   return NULL;
