@@ -49,13 +49,18 @@ resolve (GrlSource   *source,
          gchar      **out_mb_recording_id,
          gchar      **out_title,
          gchar      **out_mb_release_id,
-         gchar      **out_mb_release_group_id)
+         gchar      **out_mb_release_group_id,
+         gint        *out_album_disc_number,
+         gchar      **out_publication_date,
+         gchar      **out_creation_date,
+         gint        *out_track_number)
 {
   GList *keys;
   GrlMedia *audio;
   GrlOperationOptions *options;
   GrlRegistry *registry;
   GrlKeyID chromaprint_key, mb_release_id_key, mb_release_group_id_key;
+  GDateTime *publication_date, *creation_date;
   GError *error = NULL;
 
   registry = grl_registry_get_default ();
@@ -72,6 +77,10 @@ resolve (GrlSource   *source,
                                     GRL_METADATA_KEY_ALBUM,
                                     GRL_METADATA_KEY_MB_RECORDING_ID,
                                     GRL_METADATA_KEY_TITLE,
+                                    GRL_METADATA_KEY_ALBUM_DISC_NUMBER,
+                                    GRL_METADATA_KEY_PUBLICATION_DATE,
+                                    GRL_METADATA_KEY_CREATION_DATE,
+                                    GRL_METADATA_KEY_TRACK_NUMBER,
                                     NULL);
   options = grl_operation_options_new (NULL);
   grl_operation_options_set_resolution_flags (options, GRL_RESOLVE_NORMAL);
@@ -97,6 +106,12 @@ resolve (GrlSource   *source,
   *out_mb_release_id = g_strdup (grl_data_get_string (GRL_DATA (audio), mb_release_id_key));
   *out_mb_release_group_id = g_strdup (grl_data_get_string (GRL_DATA (audio),
                                                             mb_release_group_id_key));
+  *out_album_disc_number = grl_media_get_album_disc_number (audio);
+  publication_date = grl_media_get_publication_date (audio);
+  *out_publication_date = g_date_time_format (publication_date, "%Y-%m-%d");
+  creation_date = grl_media_get_creation_date (audio);
+  *out_creation_date = g_date_time_format (creation_date, "%Y-%m-%d");
+  *out_track_number = grl_media_get_track_number (audio);
 
   g_list_free (keys);
   g_object_unref (options);
@@ -120,32 +135,41 @@ test_resolve_fingerprint (void)
     gchar *mb_recording_id;
     gchar *title;
     gchar *mb_release_id;
+    gint album_disc_number;
+    gchar *publication_date;
+    gchar *creation_date;
+    gint track_number;
   } audios[] = {
    { FINGERPRINT_LUDOVICO_EI, 445,
      "fa34b363-79df-434f-a5b8-be4e6898543f", "Ludovico Einaudi",
-     "39f2c673-1387-4272-9db9-5f19d48e47cb", "Divenire",
-     "70088e7c-1c01-48cb-9103-ba8b500c68a4", "Primavera",
-     "931d4cfa-53c6-41cd-8ab0-a2917a7c1f3e" },
+     "ac615d26-df00-3053-9462-7636375603b4", "The Number One Classical Album 2008",
+     "8f6ac978-95cf-41e8-82fb-043624652e04", "Primavera",
+     "d73e4041-375c-4b9f-8366-46089bca304c",
+     1, "2007-11-26", "2007-11-26", 19 },
    { FINGERPRINT_NORAH_JONES, 160,
      "985c709c-7771-4de3-9024-7bda29ebe3f9", "Norah Jones",
      "f5cffa96-262c-49af-9747-3f04a1d42c78", "\u00d63 Greatest Hits 49",
      "6d8ba615-d8fe-4f99-b38f-0a17d657b1bb", "Chasing Pirates",
-     "1ee64f6c-560f-421f-83dc-7fd34e5b0674" },
+     "1ee64f6c-560f-421f-83dc-7fd34e5b0674",
+     1, "2010-03-12", "2010-03-12", 18 },
    { FINGERPRINT_TROMBONE_SH, 243,
      "cae4fd51-4d58-4d48-92c1-6198cc2e45ed", "Trombone Shorty",
      "c3418122-387b-4477-90cf-e5e6d110e054", "For True",
      "96483bdd-f219-4ae3-a94e-04feeeef22a4", "Buckjump",
-     "567621e3-b80f-4c30-af5f-2ecf0882e94a" },
+     "567621e3-b80f-4c30-af5f-2ecf0882e94a",
+     1, "2011-01-01", "2011-01-01", 1 },
    { FINGERPRINT_PHILIP_GLAS, 601,
      "5ae54dee-4dba-49c0-802a-a3b3b3adfe9b", "Philip Glass",
      "52f1f9d5-5166-4ceb-9289-6fb1a87f367c", "The Passion of Ramakrishna",
      "298e15a1-b29b-4947-9dca-ec3634f9ebde", "Part 2",
-     "2807def3-7873-4277-b079-c9a963d99993" },
+     "2807def3-7873-4277-b079-c9a963d99993",
+     1, "2012-01-01", "2012-01-01", 3 },
    { FINGERPRINT_RADIOHEAD_PA, 385,
      "a74b1b7f-71a5-4011-9441-d0b5e4122711", "Radiohead",
-     "aaf960f9-bfe9-3130-9f14-af412880c360", "Superhits of the 90's",
-     "7a7c3a58-288b-4725-93af-3b0b4fcd3870", "Paranoid Android",
-     "7c095f83-fbf8-4d88-9228-8af138ab6f12",
+     "dd02a722-bb7f-4771-9a5b-681f5556ce71", "3X plus de bruit!",
+     "9f9cf187-d6f9-437f-9d98-d59cdbd52757", "Paranoid Android",
+     "67016a2b-118d-483d-9e36-49080ae43df4",
+     1, "1997-01-01", "1997-01-01", 4,
    },
   };
 
@@ -156,7 +180,8 @@ test_resolve_fingerprint (void)
     gsize size;
     GError *error = NULL;
     gchar *mb_artist_id, *artist, *mb_album_id, *album, *mb_recording_id, *title,
-          *mb_release_id, *mb_release_group_id;
+          *mb_release_id, *mb_release_group_id, *publication_date, *creation_date;
+    gint album_disc_number, track_number;
 
     file = g_file_new_for_uri (audios[i].fingerprint_file);
     g_file_load_contents (file, NULL, &data, &size, NULL, &error);
@@ -165,7 +190,8 @@ test_resolve_fingerprint (void)
 
     resolve (source, data, audios[i].duration,
              &mb_artist_id, &artist, &mb_album_id, &album, &mb_recording_id, &title,
-             &mb_release_id, &mb_release_group_id);
+             &mb_release_id, &mb_release_group_id, &album_disc_number, &publication_date,
+             &creation_date, &track_number);
     g_free (data);
 
     g_assert_cmpstr (audios[i].title, ==, title);
@@ -184,6 +210,12 @@ test_resolve_fingerprint (void)
     g_free (mb_release_id);
     g_assert_cmpstr (audios[i].mb_album_id, ==, mb_release_group_id);
     g_free (mb_release_group_id);
+    g_assert_cmpint (audios[i].album_disc_number, ==, album_disc_number);
+    g_assert_cmpstr (audios[i].publication_date, ==, publication_date);
+    g_free (publication_date);
+    g_assert_cmpstr (audios[i].creation_date, ==, creation_date);
+    g_free (creation_date);
+    g_assert_cmpint (audios[i].track_number, ==, track_number);
   }
 }
 
